/****************************************************************************
** xtermcolors - Dynamically change xterm colors and title.
**
** Copyright (C) 2002 Jess Thrysoee <jess at thrysoee dot dk>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
****************************************************************************/

#include "xtermcolors.h"

/* The name the program was run with, stripped of any leading path. */
char *program_name;

int main(int argc, char* argv[])
{
   int c,i;

   struct controlseq* params;
   params = seqtab;

   program_name = argv[0];
   if (program_name && strrchr(program_name, '/'))
        program_name = strrchr(program_name, '/') + 1;

   while(1) {
      int longindex = 0;

      static struct option longopts[] =
      {
         {"foreground"      , 1, 0, 'f'},
         {"background"      , 1, 0, 'b'},
         {"cursor"          , 1, 0, 'c'},
         {"mouse-foreground", 1, 0, 'm'},
         {"mouse-background", 1, 0, 'n'},
         {"title"           , 1, 0, 't'},
         {"version"         , 0, 0, 'v'},
         {"usage"           , 0, 0, 'u'},
         {"help"            , 0, 0, 'h'},
         { 0                , 0, 0,  0 }
      };

      c = getopt_long(argc, argv, "f:b:c:m:n:t:vuh",
                      longopts, &longindex);
      if (c == -1)
         break;

      switch(c) {
         case 'f':
            params[FG].textparam = optarg;
            break;
         case 'b':
            params[BG].textparam = optarg;
            break;
         case 'c':
            params[CURSOR].textparam = optarg;
            break;
         case 'm':
            params[MOUSE_FG].textparam = optarg;
            break;
         case 'n':
            params[MOUSE_BG].textparam = optarg;
            break;
         case 't':
            params[TITLE].textparam = optarg;
            break;

         case 'v':
            version();

         case 'u':
         case 'h':
            usage(0);

         case '?':
         case ':':
         default :
            usage(1);
      }
   }

   if(optind < argc) {
      usage(1);
   }

   if (argc < 2)
      params = default_seqtab;

   for (i = 0; i < NSEQ; i++) {
      if (params[i].textparam) {
         printf("\033]%d;%s\007", params[i].setparam, params[i].textparam);
      }
   }

   exit(0);
}

void usage(int status)
{
   if (status) {
      fprintf(stderr, "Usage: %s [OPTION]...\n", program_name);
      fprintf(stderr, "Try `%s --help' for more information.\n",
            program_name);

    } else {

      printf("Usage: %s [OPTION]...\n", program_name);
      printf("\
Dynamically change xterm colors and title.\n\
Example: %s -f blue -b '#EFEFEF' --title='colored by xtermcolors'\n\
\n", program_name);

      printf("\
OPTIONS\n\
  -f COLOR,  --foreground=COLOR       xterm foreground color to COLOR\n\
  -b COLOR,  --background=COLOR       xterm background color to COLOR\n\
  -c COLOR,  --cursor=COLOR           cursor color to COLOR\n\
  -m COLOR,  --mouse-foreground=COLOR mouse pointer foreground color to COLOR\n\
  -n COLOR,  --mouse-background=COLOR mouse pointer background color to COLOR\n\
  -t STRING, --title=STRING           xterm title to STRING\n\
\n\
  -u, --usage, -h, --help             print usage/help message and exit\n\
  -v, --version                       print the version number of %s\
\n", program_name);
      printf ("\nReport bugs to <jess at thrysoee dot dk>.\n");
    }
   exit(status);
}

void version(void)
{
   printf ("%s %s\n", program_name, VERSION);
   printf ("\n");
   printf ("\
Copyright (C) 2002 Jess Thrysoee.\n\
This is free software; see the source for copying conditions. There is NO\n\
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
   printf ("\n");
   exit(0);
}

